package com.ruoyi.bst.order.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.order.mapper.OrderMapper;
import com.ruoyi.bst.order.domain.Order;
import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.domain.OrderQuery;
import com.ruoyi.bst.order.service.OrderService;

/**
 * 订单列表Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-26
 */
@Service
public class OrderServiceImpl implements OrderService
{
    @Autowired
    private OrderMapper orderMapper;

    /**
     * 查询订单列表
     *
     * @param id 订单列表主键
     * @return 订单列表
     */
    @Override
    public OrderVO selectOrderById(Long id)
    {
        return orderMapper.selectOrderById(id);
    }

    /**
     * 查询订单列表列表
     *
     * @param order 订单列表
     * @return 订单列表
     */
    @Override
    public List<OrderVO> selectOrderList(OrderQuery order)
    {
        return orderMapper.selectOrderList(order);
    }

    /**
     * 新增订单列表
     *
     * @param order 订单列表
     * @return 结果
     */
    @Override
    public int insertOrder(Order order)
    {
        order.setCreateTime(DateUtils.getNowDate());
        return orderMapper.insertOrder(order);
    }

    /**
     * 修改订单列表
     *
     * @param order 订单列表
     * @return 结果
     */
    @Override
    public int updateOrder(Order order)
    {
        return orderMapper.updateOrder(order);
    }

    /**
     * 批量删除订单列表
     *
     * @param ids 需要删除的订单列表主键
     * @return 结果
     */
    @Override
    public int deleteOrderByIds(Long[] ids)
    {
        return orderMapper.deleteOrderByIds(ids);
    }

    /**
     * 删除订单列表信息
     *
     * @param id 订单列表主键
     * @return 结果
     */
    @Override
    public int deleteOrderById(Long id)
    {
        return orderMapper.deleteOrderById(id);
    }
}
